package Games::TabRace;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-06-12'; # DATE
our $DIST = 'Games-TabRace'; # DIST
our $VERSION = '0.008'; # VERSION

1;
# ABSTRACT: A game played using shell tab completion

__END__

=pod

=encoding UTF-8

=head1 NAME

Games::TabRace - A game played using shell tab completion

=head1 VERSION

This document describes version 0.008 of Games::TabRace (from Perl distribution Games-TabRace), released on 2021-06-12.

=head1 SYNOPSIS

See L<tabrace>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Games-TabRace>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Games-TabRace>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-TabRace>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
